@@ -160,7 +160,7 @@ void OcularDialog::insertNewOcular()
 
 void OcularDialog::insertNewTelescope()
 {
-	telescopeTableModel->insertRows(ccdTableModel->rowCount(), 1);
+	telescopeTableModel->insertRows(telescopeTableModel->rowCount(), 1);
 	ui->telescopeListView->setCurrentIndex(telescopeTableModel->index(telescopeTableModel->rowCount() - 1, 1));
 }
 
@@ -293,8 +293,8 @@ void OcularDialog::createDialogContent()
 	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
 	connect(ui->scaleImageCircleCheckBox, SIGNAL(stateChanged(int)), this, SLOT(scaleImageCircleStateChanged(int)));
 	connect(ui->requireSelectionCheckBox, SIGNAL(stateChanged(int)), this, SLOT(requireSelectionStateChanged(int)));
-	connect(ui->checkBoxControlPanel, SIGNAL(clicked(bool)),
-	        plugin, SLOT(enableGuiPanel(bool)));
+	connect(ui->checkBoxControlPanel, SIGNAL(clicked(bool)), plugin, SLOT(enableGuiPanel(bool)));
+	connect(ui->checkBoxDecimalDegrees, SIGNAL(clicked(bool)), plugin, SLOT(setFlagDecimalDegrees(bool)));
 	
 	// The add & delete buttons
 	connect(ui->addCCD, SIGNAL(clicked()), this, SLOT(insertNewCCD()));
@@ -404,6 +404,10 @@ void OcularDialog::createDialogContent()
 	{
 		ui->checkBoxControlPanel->setChecked(true);
 	}
+	if (Oculars::appSettings()->value("use_decimal_degrees", false).toBool())
+	{
+		ui->checkBoxDecimalDegrees->setChecked(true);
+	}
 
 	//Initialize the style
 	updateStyle();
@@ -414,24 +418,23 @@ void OcularDialog::initAboutText()
 	//BM: Most of the text for now is the original contents of the About widget.
 	QString html = "<html><head><title></title></head><body>";
 
-	html += "<h1>Oculars plug-in</h1>";
-	
-	//Authors
-	QString authors = "Authors: <a href=\"mailto:treaves@silverfieldstech.com\">Timothy Reaves</a>, Bogdan Marinov";
-	html += "<h3>" + authors + "</h3>";
+	html += "<h2>" + q_("Oculars Plug-in") + "</h2><table width=\"90%\">";
+	html += "<tr width=\"30%\"><td><strong>" + q_("Version") + ":</strong></td><td>" + OCULARS_PLUGIN_VERSION + "</td></tr>";
+	html += "<tr><td><strong>" + q_("Authors") + ":</strong></td><td>Timothy Reaves &lt;treaves@silverfieldstech.com&gt;<br />Bogdan Marinov</td></tr>";
+	html += "</table>";
 
 	//Overview
-	html += "<h2>Overview</h2>";
+	html += "<h2>" + q_("Overview") + "</h2>";
 
-	html += "<p>This plugin is intended to simulate what you would see through an eyepiece.  This configuration dialog can be used to add, modify, or delete eyepieces and telescopes, as well as CCD Sensors.  Your first time running the app will populate some samples to get your started.</p>";
-	html += "<p>You can choose to scale the image you see on the screen.  This is intended to show you a better comparison of what one eyepiece/telescope combination will be like as compared to another.  The same eyepiece in two different telescopes of differing focal length will produce two different exit circles, changing the view someone.  The trade-off of this is that, with the image scaled, a good deal of the screen can be wasted.  Therefor I recommend that you leave it off, unless you feel you have a need of it.</p>";
-	html += "<p>You can toggle a crosshair in the view.  Ideally, I wanted this to be aligned to North.  I've been unable to do so.  So currently it aligns to the top of the screen.</p>";
-	html += QString("<p>You can toggle a Telrad finder; this can only be done when you have not turned on the Ocular view.  This feature draws three concentric circles of 0.5%1, 2.0%1, and 4.0%1, helping you see what you would expect to see with the naked eye through the Telrad (or similar) finder.</p>").arg(QChar(0x00B0));
-	html += "<p>If you find any issues, please let me know.  Enjoy!</p>";
+	html += "<p>" + q_("This plugin is intended to simulate what you would see through an eyepiece.  This configuration dialog can be used to add, modify, or delete eyepieces and telescopes, as well as CCD Sensors.  Your first time running the app will populate some samples to get your started.") + "</p>";
+	html += "<p>" + q_("You can choose to scale the image you see on the screen.  This is intended to show you a better comparison of what one eyepiece/telescope combination will be like as compared to another.  The same eyepiece in two different telescopes of differing focal length will produce two different exit circles, changing the view someone.  The trade-off of this is that, with the image scaled, a good deal of the screen can be wasted.  Therefore I recommend that you leave it off, unless you feel you have a need of it.") + "</p>";
+	html += "<p>" + q_("You can toggle a crosshair in the view.  Ideally, I wanted this to be aligned to North.  I've been unable to do so.  So currently it aligns to the top of the screen.") + "</p>";
+	html += "<p>" + QString(q_("You can toggle a Telrad finder; this can only be done when you have not turned on the Ocular view.  This feature draws three concentric circles of 0.5%1, 2.0%1, and 4.0%1, helping you see what you would expect to see with the naked eye through the Telrad (or similar) finder.")).arg(QChar(0x00B0)) + "</p>";
+	html += "<p>" + q_("If you find any issues, please let me know.  Enjoy!") + "</p>";
 
 	//Keys
-	html += "<h2>Hot Keys</h2>";
-	html += "<p>The plug-in's key bindings can be edited in the General Tab.</p>";
+	html += "<h2>" + q_("Hot Keys") + "</h2>";
+	html += "<p>" + q_("The plug-in's key bindings can be edited in the General Tab.") + "</p>";
 
 	StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
 	Q_ASSERT(gui);
@@ -443,22 +446,26 @@ void OcularDialog::initAboutText()
 	QString ocularString = ocularShortcut.toString(QKeySequence::NativeText);
 	ocularString = Qt::escape(ocularString);
 	if (ocularString.isEmpty())
-		ocularString = "[no key defined]";
+		ocularString = q_("[no key defined]");
 	QKeySequence menuShortcut = actionMenu->shortcut();
 	QString menuString = menuShortcut.toString(QKeySequence::NativeText);
 	menuString = Qt::escape(menuString);
 	if (menuString.isEmpty())
-		menuString = "[no key defined]";
+		menuString = q_("[no key defined]");
 
 	html += "<ul>";
 	html += "<li>";
-	html += QString("<strong>%1:</strong> Switches on/off the ocular overlay.").arg(ocularString);
+	html += QString("<strong>%1:</strong> %2").arg(ocularString).arg(q_("Switches on/off the ocular overlay."));
 	html += "</li>";
 	
 	html += "<li>";
-	html += QString("<strong>%1:</strong> Opens the pop-up navigation menu.").arg(menuString);
+	html += QString("<strong>%1:</strong> %2").arg(menuString).arg(q_("Opens the pop-up navigation menu."));
 	html += "</li>";
 	html += "</ul>";
 	html += "</body></html>";
+
+	QString htmlStyleSheet(gui->getStelStyle().htmlStyleSheet);
+	ui->textBrowser->document()->setDefaultStyleSheet(htmlStyleSheet);
+
 	ui->textBrowser->setHtml(html);
 }
