@@ -17,6 +17,7 @@
  */
 
 #include "Pulsar.hpp"
+#include "Pulsars.hpp"
 #include "StelObject.hpp"
 #include "StelPainter.hpp"
 #include "StelApp.hpp"
@@ -35,6 +36,8 @@
 #include <QVariant>
 #include <QList>
 
+#define PSR_INERTIA 1.0e45 /* Typical moment of inertia for a pulsar */
+
 StelTextureSP Pulsar::markerTexture;
 
 Pulsar::Pulsar(const QVariantMap& map)
@@ -45,16 +48,33 @@ Pulsar::Pulsar(const QVariantMap& map)
 		return;
 		
 	designation  = map.value("designation").toString();
-	distance = map.value("distance").toFloat();
+	parallax = map.value("parallax").toFloat();
 	period = map.value("period").toDouble();
+	bperiod = map.value("bperiod").toDouble();
+	frequency = map.value("frequency").toDouble();
+	pfrequency = map.value("pfrequency").toDouble();
+	pderivative = map.value("pderivative").toDouble();
+	dmeasure = map.value("dmeasure").toDouble();
+	eccentricity = map.value("eccentricity").toDouble();	
 	RA = StelUtils::getDecAngle(map.value("RA").toString());
-	DE = StelUtils::getDecAngle(map.value("DE").toString());
-	ntype = map.value("ntype").toInt();
-	We = map.value("We").toFloat();
+	DE = StelUtils::getDecAngle(map.value("DE").toString());	
 	w50 = map.value("w50").toFloat();
 	s400 = map.value("s400").toFloat();
 	s600 = map.value("s600").toFloat();
 	s1400 = map.value("s1400").toFloat();
+	distance = map.value("distance").toFloat();
+	notes = map.value("notes").toString();
+
+	// If barycentric period not set then calculate it
+	if (period==0 && frequency>0)
+	{
+		period = 1/frequency;
+	}
+	// If barycentric period derivative not set then calculate it
+	if (pderivative==0)
+	{
+		pderivative = getP1(period, pfrequency);
+	}
 
 	initialized = true;
 }
@@ -68,16 +88,22 @@ QVariantMap Pulsar::getMap(void)
 {
 	QVariantMap map;
 	map["designation"] = designation;
-	map["distance"] = distance;
+	map["parallax"] = parallax;
+	map["bperiod"] = bperiod;
+	map["frequency"] = frequency;
+	map["pfrequency"] = pfrequency;
+	map["pderivative"] = pderivative;
+	map["dmeasure"] = dmeasure;
+	map["eccentricity"] = eccentricity;	
 	map["RA"] = RA;
 	map["DE"] = DE;
-	map["period"] = period;
-	map["ntype"] = ntype;	
-	map["We"] = We;
+	map["period"] = period;	
 	map["w50"] = w50;
 	map["s400"] = s400;
 	map["s600"] = s600;
 	map["s1400"] = s1400;
+	map["distance"] = distance;
+	map["notes"] = notes;
 
 	return map;
 }
@@ -99,25 +125,57 @@ QString Pulsar::getInfoString(const StelCore* core, const InfoStringGroup& flags
 	}
 
 	if (flags&Extra1)
-	    oss << q_("Type: <b>%1</b>").arg(q_("pulsar")) << "<br />";
+	{
+		oss << q_("Type: <b>%1</b>").arg(q_("pulsar")) << "<br />";
+	}
 
 	// Ra/Dec etc.
 	oss << getPositionInfoString(core, flags);
 
 	if (flags&Extra1)
 	{
-		oss << q_("Barycentric period: %1 s").arg(QString::number(period, 'f', 16)) << "<br>";
+		if (period>0)
+		{
+			//TRANSLATORS: Unit of measure for period - seconds
+			oss << q_("Barycentric period: %1 s").arg(QString::number(period, 'f', 16)) << "<br>";
+		}
+		if (pderivative>0)
+		{
+			oss << q_("Time derivative of barycentric period: %1").arg(QString::number(pderivative, 'e', 5)) << "<br>";
+		}
+		if (dmeasure>0)
+		{
+			oss << QString("%1 %2 %3<sup>-3</sup> %4 %5")
+			       .arg(q_("Dispersion measure:"))
+			       .arg(QString::number(dmeasure, 'f', 3))
+			       //TRANSLATORS: Unit of measure for distance - centimeters
+			       .arg(q_("cm"))
+			       .arg(QChar(0x00B7))
+			       //TRANSLATORS: Unit of measure for distance - parsecs
+			       .arg(q_("pc"));
+			oss << "<br>";
+		}
+		double edot = getEdot(period, pderivative);
+		if (edot>0)
+		{
+			oss << q_("Spin down energy loss rate: %1 ergs/s").arg(QString::number(edot, 'e', 2)) << "<br>";
+		}
+		if (bperiod>0)
+		{
+			oss << q_("Binary period of pulsar: %1 days").arg(QString::number(bperiod, 'f', 12)) << "<br>";
+		}
+		if (eccentricity>0)
+		{
+			oss << q_("Eccentricity: %1").arg(QString::number(eccentricity, 'f', 10)) << "<br>";
+		}
+		if (parallax>0)
+		{
+			//TRANSLATORS: Unit of measure for annual parallax - milliarcseconds
+			oss << q_("Annual parallax: %1 mas").arg(parallax) << "<br>";
+		}
 		if (distance>0)
 		{
-			oss << q_("Distance: %1 kpc (%2 ly)").arg(distance).arg(distance*3261.563777) << "<br>";
-		}
-		if (ntype>0)
-		{
-			oss << q_("Type of pulsar: %1").arg(getPulsarTypeInfoString(ntype)) << "<br>";
-		}
-		if (We>0)
-		{
-			oss << q_("Equivalent width of the integrated pulse profile: %1 ms").arg(QString::number(We, 'f', 2)) << "<br>";
+			oss << q_("Distance based on electron density model: %1 kpc (%2 ly)").arg(distance).arg(distance*3261.563777) << "<br>";
 		}
 		if (w50>0)
 		{
@@ -159,6 +217,10 @@ QString Pulsar::getInfoString(const StelCore* core, const InfoStringGroup& flags
 			       // TRANSLATORS: mJy is milliJansky(10-26W/m2/Hz)
 			       .arg(q_("mJy")) << "<br>";
 		}
+		if (notes.length()>0)
+		{
+			oss << "<br>" << q_("Notes: %1").arg(getPulsarTypeInfoString(notes)) << "<br>";
+		}
 	}
 
 	postProcessInfoString(str, flags);
@@ -183,7 +245,83 @@ float Pulsar::getVMagnitude(const StelCore* core, bool withExtinction) const
 	// Calculate fake visual magnitude as function by distance - minimal magnitude is 6
 	float vmag = distance + 6.f;
 
-	return vmag + extinctionMag;
+	if (GETSTELMODULE(Pulsars)->getDisplayMode())
+	{
+		return 3.f;
+	}
+	else
+	{
+		return vmag + extinctionMag;
+	}
+}
+
+double Pulsar::getEdot(double p0, double p1) const
+{
+	if (p0>0 && p1!=0)
+	{
+		// Calculate spin down energy loss rate (ergs/s)
+		return 4.0 * M_PI * M_PI * PSR_INERTIA * p1 / pow(p0,3);
+	}
+	else
+	{
+		return 0.0;
+	}
+}
+
+double Pulsar::getP1(double p0, double f1) const
+{
+	if (p0>0 && f1!=0)
+	{
+		// Calculate derivative of barycentric period
+		return -1.0 * p0 * p0 * f1;
+	}
+	else
+	{
+		return 0.0;
+	}
+}
+
+
+QString Pulsar::getPulsarTypeInfoString(QString pcode) const
+{
+	QStringList out;
+
+	if (pcode.contains("AXP"))
+	{
+		out.append(q_("anomalous X-ray pulsar or soft gamma-ray repeater with detected pulsations"));
+	}
+
+	if (pcode.contains("BINARY") || bperiod>0)
+	{
+		out.append(q_("has one or more binary companions"));
+	}
+
+	if (pcode.contains("HE"))
+	{
+		out.append(q_("with pulsed emission from radio to infrared or higher frequencies"));
+	}
+
+	if (pcode.contains("NRAD"))
+	{
+		out.append(q_("with pulsed emission only at infrared or higher frequencies"));
+	}
+
+	if (pcode.contains("RADIO"))
+	{
+		out.append(q_("with pulsed emission in the radio band"));
+	}
+
+	if (pcode.contains("RRAT"))
+	{
+		out.append(q_("with intermittently pulsed radio emission"));
+	}
+
+	if (pcode.contains("XINS"))
+	{
+		out.append(q_("isolated neutron star with pulsed thermal X-ray emission but no detectable radio emission"));
+	}
+
+	return out.join(",<br />");
 }
 
 double Pulsar::getAngularSize(const StelCore*) const
@@ -201,6 +339,9 @@ void Pulsar::draw(StelCore* core, StelPainter& painter)
 	StelSkyDrawer* sd = core->getSkyDrawer();	
 
 	Vec3f color = Vec3f(0.4f,0.5f,1.2f);
+	if (StelApp::getInstance().getVisionModeNight())
+		color = StelUtils::getNightColor(color);
+
 	double mag = getVMagnitude(core, true);
 
 	StelUtils::spheToRect(RA, DE, XYZ);			
@@ -216,69 +357,16 @@ void Pulsar::draw(StelCore* core, StelPainter& painter)
 		float shift = 5.f + size/1.6f;
 		if (labelsFader.getInterstate()<=0.f)
 		{
-			painter.drawSprite2dMode(XYZ, 5);
-			painter.drawText(XYZ, designation, 0, shift, shift, false);
+			if (GETSTELMODULE(Pulsars)->getDisplayMode())
+			{
+				painter.drawSprite2dMode(XYZ, 4);
+				painter.drawText(XYZ, " ", 0, shift, shift, false);
+			}
+			else
+			{
+				painter.drawSprite2dMode(XYZ, 5);
+				painter.drawText(XYZ, designation, 0, shift, shift, false);
+			}
 		}
 	}
 }
-
-QString Pulsar::getPulsarTypeInfoString(const int flags) const
-{
-	QStringList out;
-
-	if (flags&C)
-	{
-		// TRANSLATORS: Type of pulsar
-		out.append(q_("globular cluster association"));
-	}
-
-	if (flags&S)
-	{
-		// TRANSLATORS: Type of pulsar
-		out.append(q_("SNR association"));
-	}
-
-	if (flags&G)
-	{
-		// TRANSLATORS: Type of pulsar
-		out.append(q_("glitches in period"));
-	}
-
-	if (flags&B)
-	{
-		// TRANSLATORS: Type of pulsar
-		out.append(q_("binary or multiple pulsar"));
-	}
-
-	if (flags&M)
-	{
-		// TRANSLATORS: Type of pulsar
-		out.append(q_("millisecond pulsar"));
-	}
-
-	if (flags&R)
-	{
-		// TRANSLATORS: Type of pulsar
-		out.append(q_("recycled pulsar"));
-	}
-
-	if (flags&I)
-	{
-		// TRANSLATORS: Type of pulsar
-		out.append(q_("radio interpulse"));
-	}
-
-	if (flags&H)
-	{
-		// TRANSLATORS: Type of pulsar
-		out.append(q_("optical, X-ray or Gamma-ray pulsed emission (high energy)"));
-	}
-
-	if (flags&E)
-	{
-		// TRANSLATORS: Type of pulsar
-		out.append(q_("extragalactic (in MC) pulsar"));
-	}
-
-	return out.join(", ");
-}
