@@ -21,6 +21,7 @@
 #include "StelApp.hpp"
 #include "StelCore.hpp"
 #include "StelGui.hpp"
+#include "StelGuiItems.hpp"
 #include "StelLocaleMgr.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelObjectMgr.hpp"
@@ -29,18 +30,28 @@
 #include "StelFileMgr.hpp"
 #include "StelUtils.hpp"
 #include "StelTranslator.hpp"
-#include "Pulsars.hpp"
+#include "LabelMgr.hpp"
 #include "Pulsar.hpp"
+#include "Pulsars.hpp"
+#include "PulsarsDialog.hpp"
 
+#include <QNetworkAccessManager>
+#include <QNetworkReply>
+#include <QKeyEvent>
+#include <QAction>
+#include <QProgressBar>
 #include <QDebug>
 #include <QFileInfo>
 #include <QFile>
+#include <QTimer>
 #include <QVariantMap>
 #include <QVariant>
 #include <QList>
 #include <QSharedPointer>
 #include <QStringList>
 
+#define CATALOG_FORMAT_VERSION 2 /* Version of format of catalog */
+
 /*
  This method is the one called automatically by the StelModuleMgr just 
  after loading the dynamic library
@@ -59,7 +70,7 @@ StelPluginInfo PulsarsStelPluginInterface::getPluginInfo() const
 	info.displayedName = N_("Pulsars");
 	info.authors = "Alexander Wolf";
 	info.contact = "alex.v.wolf@gmail.com";
-	info.description = N_("This plugin plots the position of various pulsars, with object information about each one. Pulsar data is derived from 'Catalog of Pulsars' (Taylor+ 1995).<br><br>Note: pulsar identifiers have the prefix \"PSR\"");
+	info.description = N_("This plugin plots the position of various pulsars, with object information about each one.");
 	return info;
 }
 
@@ -70,9 +81,12 @@ Q_EXPORT_PLUGIN2(Pulsars, PulsarsStelPluginInterface)
  Constructor
 */
 Pulsars::Pulsars()
+	: progressBar(NULL)
 {
 	setObjectName("Pulsars");
-	font.setPixelSize(StelApp::getInstance().getSettings()->value("gui/base_font_size", 13).toInt());
+	configDialog = new PulsarsDialog();
+	conf = StelApp::getInstance().getSettings();
+	font.setPixelSize(conf->value("gui/base_font_size", 13).toInt());
 }
 
 /*
@@ -80,7 +94,7 @@ Pulsars::Pulsars()
 */
 Pulsars::~Pulsars()
 {
-	//
+	delete configDialog;
 }
 
 void Pulsars::deinit()
@@ -110,10 +124,29 @@ void Pulsars::init()
 	{
 		StelFileMgr::makeSureDirExistsAndIsWritable(StelFileMgr::getUserDir()+"/modules/Pulsars");
 
-		jsonCatalogPath = StelFileMgr::findFile("modules/Pulsars", (StelFileMgr::Flags)(StelFileMgr::Directory|StelFileMgr::Writable)) + "/catalog.json";
+		// If no settings in the main config file, create with defaults
+		if (!conf->childGroups().contains("Pulsars"))
+		{
+			qDebug() << "Pulsars::init no Pulsars section exists in main config file - creating with defaults";
+			restoreDefaultConfigIni();
+		}
+
+		// populate settings from main config file.
+		readSettingsFromConfig();
+
+		jsonCatalogPath = StelFileMgr::findFile("modules/Pulsars", (StelFileMgr::Flags)(StelFileMgr::Directory|StelFileMgr::Writable)) + "/pulsars.json";
 
 		texPointer = StelApp::getInstance().getTextureManager().createTexture("textures/pointeur2.png");
 		Pulsar::markerTexture = StelApp::getInstance().getTextureManager().createTexture(":/Pulsars/pulsar.png");
+
+		// key bindings and other actions
+		// TRANSLATORS: Title of a group of key bindings in the Help window
+		QString groupName = N_("Plugin Key Bindings");
+		StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
+		gui->addGuiActions("actionShow_Pulsars_ConfigDialog", N_("Pulsars configuration window"), "", groupName, true);
+
+		connect(gui->getGuiActions("actionShow_Pulsars_ConfigDialog"), SIGNAL(toggled(bool)), configDialog, SLOT(setVisible(bool)));
+		connect(configDialog, SIGNAL(visibleChanged(bool)), gui->getGuiActions("actionShow_Pulsars_ConfigDialog"), SLOT(setChecked(bool)));
 	}
 	catch (std::runtime_error &e)
 	{
@@ -121,24 +154,41 @@ void Pulsars::init()
 		return;
 	}
 
+	// A timer for hiding alert messages
+	messageTimer = new QTimer(this);
+	messageTimer->setSingleShot(true);   // recurring check for update
+	messageTimer->setInterval(9000);      // 6 seconds should be enough time
+	messageTimer->stop();
+	connect(messageTimer, SIGNAL(timeout()), this, SLOT(messageTimeout()));
+
 	// If the json file does not already exist, create it from the resource in the Qt resource
 	if(QFileInfo(jsonCatalogPath).exists())
 	{
-		if (getJsonFileVersion() != PULSARS_PLUGIN_VERSION)
+		if (getJsonFileVersion() < CATALOG_FORMAT_VERSION)
 		{
 			restoreDefaultJsonFile();
 		}
 	}
 	else
 	{
-		qDebug() << "Pulsars::init catalog.json does not exist - copying default file to " << jsonCatalogPath;
+		qDebug() << "Pulsars::init pulsars.json does not exist - copying default file to " << jsonCatalogPath;
 		restoreDefaultJsonFile();
 	}
 
-	qDebug() << "Pulsars::init using catalog.json file: " << jsonCatalogPath;
+	qDebug() << "Pulsars::init using pulsars.json file: " << jsonCatalogPath;
 
 	readJsonFile();
 
+	// Set up download manager and the update schedule
+	downloadMgr = new QNetworkAccessManager(this);
+	connect(downloadMgr, SIGNAL(finished(QNetworkReply*)), this, SLOT(updateDownloadComplete(QNetworkReply*)));
+	updateState = CompleteNoUpdates;
+	updateTimer = new QTimer(this);
+	updateTimer->setSingleShot(false);   // recurring check for update
+	updateTimer->setInterval(13000);     // check once every 13 seconds to see if it is time for an update
+	connect(updateTimer, SIGNAL(timeout()), this, SLOT(checkForUpdate()));
+	updateTimer->start();
+
 	GETSTELMODULE(StelObjectMgr)->registerStelObjectMgr(this);
 }
 
@@ -266,23 +316,29 @@ void Pulsars::restoreDefaultJsonFile(void)
 	if (QFileInfo(jsonCatalogPath).exists())
 		backupJsonFile(true);
 
-	QFile src(":/Pulsars/catalog.json");
+	QFile src(":/Pulsars/pulsars.json");
 	if (!src.copy(jsonCatalogPath))
 	{
 		qWarning() << "Pulsars::restoreDefaultJsonFile cannot copy json resource to " + jsonCatalogPath;
 	}
 	else
 	{
-		qDebug() << "Pulsars::init copied default catalog.json to " << jsonCatalogPath;
+		qDebug() << "Pulsars::init copied default pulsars.json to " << jsonCatalogPath;
 		// The resource is read only, and the new file inherits this...  make sure the new file
 		// is writable by the Stellarium process so that updates can be done.
 		QFile dest(jsonCatalogPath);
 		dest.setPermissions(dest.permissions() | QFile::WriteOwner);
+
+		// Make sure that in the case where an online update has previously been done, but
+		// the json file has been manually removed, that an update is schreduled in a timely
+		// manner
+		conf->remove("Pulsars/last_update");
+		lastUpdate = QDateTime::fromString("2012-05-24T12:00:00", Qt::ISODate);
 	}
 }
 
 /*
-  Creates a backup of the catalog.json file called catalog.json.old
+  Creates a backup of the pulsars.json file called pulsars.json.old
 */
 bool Pulsars::backupJsonFile(bool deleteOriginal)
 {
@@ -303,14 +359,14 @@ bool Pulsars::backupJsonFile(bool deleteOriginal)
 		{
 			if (!old.remove())
 			{
-				qWarning() << "Pulsars::backupJsonFile WARNING - could not remove old catalog.json file";
+				qWarning() << "Pulsars::backupJsonFile WARNING - could not remove old pulsars.json file";
 				return false;
 			}
 		}
 	}
 	else
 	{
-		qWarning() << "Pulsars::backupJsonFile WARNING - failed to copy catalog.json to catalog.json.old";
+		qWarning() << "Pulsars::backupJsonFile WARNING - failed to copy pulsars.json to pulsars.json.old";
 		return false;
 	}
 
@@ -363,9 +419,9 @@ void Pulsars::setPSRMap(const QVariantMap& map)
 	}
 }
 
-const QString Pulsars::getJsonFileVersion(void)
+int Pulsars::getJsonFileVersion(void)
 {
-	QString jsonVersion("unknown");
+	int jsonVersion = -1;
 	QFile jsonPSRCatalogFile(jsonCatalogPath);
 	if (!jsonPSRCatalogFile.open(QIODevice::ReadOnly))
 	{
@@ -377,12 +433,7 @@ const QString Pulsars::getJsonFileVersion(void)
 	map = StelJsonParser::parse(&jsonPSRCatalogFile).toMap();
 	if (map.contains("version"))
 	{
-		QString creator = map.value("version").toString();
-		QRegExp vRx(".*(\\d+\\.\\d+\\.\\d+).*");
-		if (vRx.exactMatch(creator))
-		{
-			jsonVersion = vRx.capturedTexts().at(1);
-		}
+		jsonVersion = map.value("version").toInt();
 	}
 
 	jsonPSRCatalogFile.close();
@@ -399,3 +450,164 @@ PulsarP Pulsars::getByID(const QString& id)
 	}
 	return PulsarP();
 }
+
+bool Pulsars::configureGui(bool show)
+{
+	if (show)
+	{
+		StelGui* gui = dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
+		gui->getGuiActions("actionShow_Pulsars_ConfigDialog")->setChecked(true);
+	}
+
+	return true;
+}
+
+void Pulsars::restoreDefaults(void)
+{
+	restoreDefaultConfigIni();
+	restoreDefaultJsonFile();
+	readJsonFile();
+	readSettingsFromConfig();
+}
+
+void Pulsars::restoreDefaultConfigIni(void)
+{
+	conf->beginGroup("Pulsars");
+
+	// delete all existing Pulsars settings...
+	conf->remove("");
+
+	conf->setValue("distribution_enabled", false);
+	conf->setValue("updates_enabled", true);
+	conf->setValue("url", "http://stellarium.org/json/pulsars.json");
+	conf->setValue("update_frequency_days", 100);
+	conf->endGroup();
+}
+
+void Pulsars::readSettingsFromConfig(void)
+{
+	conf->beginGroup("Pulsars");
+
+	updateUrl = conf->value("url", "http://stellarium.org/json/pulsars.json").toString();
+	updateFrequencyDays = conf->value("update_frequency_days", 100).toInt();
+	lastUpdate = QDateTime::fromString(conf->value("last_update", "2012-05-24T12:00:00").toString(), Qt::ISODate);
+	updatesEnabled = conf->value("updates_enabled", true).toBool();
+	distributionEnabled = conf->value("distribution_enabled", false).toBool();
+
+	conf->endGroup();
+}
+
+void Pulsars::saveSettingsToConfig(void)
+{
+	conf->beginGroup("Pulsars");
+
+	conf->setValue("url", updateUrl);
+	conf->setValue("update_frequency_days", updateFrequencyDays);
+	conf->setValue("updates_enabled", updatesEnabled );
+	conf->setValue("distribution_enabled", distributionEnabled);
+
+	conf->endGroup();
+}
+
+int Pulsars::getSecondsToUpdate(void)
+{
+	QDateTime nextUpdate = lastUpdate.addSecs(updateFrequencyDays * 3600 * 24);
+	return QDateTime::currentDateTime().secsTo(nextUpdate);
+}
+
+void Pulsars::checkForUpdate(void)
+{
+	if (updatesEnabled && lastUpdate.addSecs(updateFrequencyDays * 3600 * 24) <= QDateTime::currentDateTime())
+		updateJSON();
+}
+
+void Pulsars::updateJSON(void)
+{
+	if (updateState==Pulsars::Updating)
+	{
+		qWarning() << "Pulsars: already updating...  will not start again current update is complete.";
+		return;
+	}
+	else
+	{
+		qDebug() << "Pulsars: starting update...";
+	}
+
+	lastUpdate = QDateTime::currentDateTime();
+	conf->setValue("Pulsars/last_update", lastUpdate.toString(Qt::ISODate));
+
+	emit(jsonUpdateComplete());
+
+	updateState = Pulsars::Updating;
+
+	emit(updateStateChanged(updateState));
+	updateFile.clear();
+
+	if (progressBar==NULL)
+		progressBar = StelApp::getInstance().getGui()->addProgressBar();
+
+	progressBar->setValue(0);
+	progressBar->setMaximum(updateUrl.size());
+	progressBar->setVisible(true);
+	progressBar->setFormat("Update pulsars");
+
+	QNetworkRequest request;
+	request.setUrl(QUrl(updateUrl));
+	request.setRawHeader("User-Agent", QString("Mozilla/5.0 (Stellarium Pulsars Plugin %1; http://stellarium.org/)").arg(PULSARS_PLUGIN_VERSION).toUtf8());
+	downloadMgr->get(request);
+
+	progressBar->setValue(100);
+	delete progressBar;
+	progressBar = NULL;
+
+	updateState = CompleteUpdates;
+
+	emit(updateStateChanged(updateState));
+	emit(jsonUpdateComplete());
+}
+
+void Pulsars::updateDownloadComplete(QNetworkReply* reply)
+{
+	// check the download worked, and save the data to file if this is the case.
+	if (reply->error() != QNetworkReply::NoError)
+	{
+		qWarning() << "Pulsars::updateDownloadComplete FAILED to download" << reply->url() << " Error: " << reply->errorString();
+	}
+	else
+	{
+		// download completed successfully.
+		try
+		{
+			QString jsonFilePath = StelFileMgr::findFile("modules/Pulsars", StelFileMgr::Flags(StelFileMgr::Writable|StelFileMgr::Directory)) + "/pulsars.json";
+			QFile jsonFile(jsonFilePath);
+			if (jsonFile.exists())
+				jsonFile.remove();
+
+			jsonFile.open(QIODevice::WriteOnly | QIODevice::Text);
+			jsonFile.write(reply->readAll());
+			jsonFile.close();
+		}
+		catch (std::runtime_error &e)
+		{
+			qWarning() << "Pulsars::updateDownloadComplete: cannot write JSON data to file:" << e.what();
+		}
+
+	}
+
+	if (progressBar)
+		progressBar->setValue(100);
+}
+
+void Pulsars::displayMessage(const QString& message, const QString hexColor)
+{
+	messageIDs << GETSTELMODULE(LabelMgr)->labelScreen(message, 30, 30 + (20*messageIDs.count()), true, 16, hexColor);
+	messageTimer->start();
+}
+
+void Pulsars::messageTimeout(void)
+{
+	foreach(int i, messageIDs)
+	{
+		GETSTELMODULE(LabelMgr)->deleteLabel(i);
+	}
+}
