@@ -310,8 +310,12 @@ StelObjectP Satellites::searchByNameI18n(const QString& nameI18n) const
 {
 	if (!hintFader || StelApp::getInstance().getCore()->getCurrentLocation().planetName != earth->getEnglishName())
 		return NULL;
-
+	
 	QString objw = nameI18n.toUpper();
+	
+	StelObjectP result = searchByNoradNumber(objw);
+	if (result)
+		return result;
 
 	foreach(const SatelliteP& sat, satellites)
 	{
@@ -331,6 +335,11 @@ StelObjectP Satellites::searchByName(const QString& englishName) const
 		return NULL;
 
 	QString objw = englishName.toUpper();
+	
+	StelObjectP result = searchByNoradNumber(objw);
+	if (result)
+		return result;
+	
 	foreach(const SatelliteP& sat, satellites)
 	{
 		if (sat->initialized && sat->visible)
@@ -343,6 +352,34 @@ StelObjectP Satellites::searchByName(const QString& englishName) const
 	return NULL;
 }
 
+StelObjectP Satellites::searchByNoradNumber(const QString &noradNumber) const
+{
+	if (!hintFader || StelApp::getInstance().getCore()->getCurrentLocation().planetName != earth->getEnglishName())
+		return NULL;
+	
+	// If the search string is a catalog number...
+	QRegExp regExp("^(NORAD)\\s*(\\d+)\\s*$");
+	if (regExp.exactMatch(noradNumber))
+	{
+		QString numberString = regExp.capturedTexts().at(2);
+		bool ok;
+		int number = numberString.toInt(&ok);
+		if (!ok)
+			return StelObjectP();
+		
+		foreach(const SatelliteP& sat, satellites)
+		{
+			if (sat->initialized && sat->visible)
+			{
+				if (sat->getCatalogNumberString() == numberString)
+					return qSharedPointerCast<StelObject>(sat);
+			}
+		}
+	}
+	
+	return StelObjectP();
+}
+
 QStringList Satellites::listMatchingObjectsI18n(const QString& objPrefix, int maxNbItem) const
 {
 	QStringList result;
@@ -352,6 +389,16 @@ QStringList Satellites::listMatchingObjectsI18n(const QString& objPrefix, int ma
 
 	QString objw = objPrefix.toUpper();
 
+	QString numberPrefix;
+	QRegExp regExp("^(NORAD)\\s*(\\d+)\\s*$");
+	if (regExp.exactMatch(objw))
+	{
+		QString numberString = regExp.capturedTexts().at(2);
+		bool ok;
+		int number = numberString.toInt(&ok);
+		if (ok)
+			numberPrefix = numberString;
+	}
 	foreach(const SatelliteP& sat, satellites)
 	{
 		if (sat->initialized && sat->visible)
@@ -360,6 +407,10 @@ QStringList Satellites::listMatchingObjectsI18n(const QString& objPrefix, int ma
 			{
 				result << sat->getNameI18n().toUpper();
 			}
+			else if (sat->getCatalogNumberString().left(numberPrefix.length()) == numberPrefix)
+			{
+				result << QString("NORAD %1").arg(sat->getCatalogNumberString());
+			}
 		}
 	}
 
@@ -1111,7 +1162,9 @@ void Satellites::update(double deltaTime)
 
 void Satellites::draw(StelCore* core)
 {
-	if (core->getCurrentLocation().planetName != earth->getEnglishName() || (!hintFader && hintFader.getInterstate() <= 0.))
+	if (core->getCurrentLocation().planetName != earth->getEnglishName() ||
+			(core->getJDay()<2436116.3115)                               || // do not draw anything before Oct 4, 1957, 19:28:34GMT ;-)
+			(!hintFader && hintFader.getInterstate() <= 0.))
 		return;
 
 	StelProjectorP prj = core->getProjection(StelCore::FrameAltAz);
@@ -1148,7 +1201,10 @@ void Satellites::drawPointer(StelCore* core, StelPainter& painter)
 		// Compute 2D pos and return if outside screen
 		if (!prj->project(pos, screenpos))
 			return;
-		glColor3f(0.4f,0.5f,0.8f);
+		if (StelApp::getInstance().getVisionModeNight())
+			glColor3f(0.8f,0.0f,0.0f);
+		else
+			glColor3f(0.4f,0.5f,0.8f);
 		texPointer->bind();
 
 		glEnable(GL_TEXTURE_2D);
