@@ -265,6 +265,10 @@ public slots:
 	QString getDefaultLocationID() const;
 	//! Set the location to use by default at startup
 	void setDefaultLocationID(const QString& id);
+	//! Return to the default location.
+	void returnToDefaultLocation();
+	//! Return to the default location and set default landscape with atmosphere and fog effects
+	void returnToHome();
 
 	//! Set the current date in Julian Day
 	void setJDay(double JD);
