@@ -101,11 +101,14 @@ public:
 	//! designation.
 	static QString renderProvisionalDesignationinHtml(QString plainText);
 
+	//! set value for semi-major axis in AU
+	void setSemiMajorAxis(double value);
 
 private:
 	int minorPlanetNumber;
 	double absoluteMagnitude;
 	double slopeParameter;
+	double semiMajorAxis;
 
 	bool nameIsProvisionalDesignation;
 	QString provisionalDesignationHtml;
