@@ -258,8 +258,11 @@ void StarMgr::drawPointer(StelPainter& sPainter, const StelCore* core)
 		if (!sPainter.getProjector()->project(pos, screenpos))
 			return;
 
-		const Vec3f& c(obj->getInfoColor());
-		sPainter.setColor(c[0],c[1],c[2]);
+		Vec3f c(obj->getInfoColor());
+		if (StelApp::getInstance().getVisionModeNight())
+			c = StelUtils::getNightColor(c);
+
+		sPainter.setColor(c[0], c[1], c[2]);
 		texPointer->bind();
 		sPainter.enableTexture2d(true);
 		glEnable(GL_BLEND);
