@@ -41,6 +41,7 @@
 #include "StelStyle.hpp"
 #include "StelLogger.hpp"
 #include "StelGui.hpp"
+#include "StelGuiItems.hpp"
 
 HelpDialog::HelpDialog()
 {
@@ -69,6 +70,10 @@ HelpDialog::HelpDialog()
 #endif
 
 	group = N_("When a Script is Running");
+
+	setKey(group, "", "4", N_("Stop currently running script"));
+	setKey(group, "", "5", N_("Pause script execution"));
+	setKey(group, "", "6", N_("Resume script execution"));
 	setKey(group, "", "J", N_("Slow down the script execution rate"));
 	setKey(group, "", "L", N_("Speed up the script execution rate"));
 	setKey(group, "", "K", N_("Set the normal script execution rate"));
@@ -101,11 +106,32 @@ void HelpDialog::styleChanged()
 	}
 }
 
+void HelpDialog::updateIconsColor()
+{
+	QPixmap pixmap(50, 50);
+	QStringList icons;
+	icons << "help" << "info" << "logs";
+	bool redIcon = false;
+	if (StelApp::getInstance().getVisionModeNight())
+		redIcon = true;
+
+	foreach(const QString &iconName, icons)
+	{
+		pixmap.load(":/graphicGui/tabicon-" + iconName +".png");
+		if (redIcon)
+			pixmap = StelButton::makeRed(pixmap);
+
+		ui->stackListWidget->item(icons.indexOf(iconName))->setIcon(QIcon(pixmap));
+	}
+}
+
 void HelpDialog::createDialogContent()
 {
 	ui->setupUi(dialog);
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
+	connect(&StelApp::getInstance(), SIGNAL(colorSchemeChanged(QString)), this, SLOT(updateIconsColor()));
 	ui->stackedWidget->setCurrentIndex(0);
+	updateIconsColor();
 	ui->stackListWidget->setCurrentRow(0);
 	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
 
