@@ -20,6 +20,7 @@
 
 #include "Dialog.hpp"
 #include "LocationDialog.hpp"
+#include "LandscapeMgr.hpp"
 #include "StelLocationMgr.hpp"
 #include "ui_locationDialogGui.h"
 #include "StelApp.hpp"
@@ -91,7 +92,8 @@ void LocationDialog::createDialogContent()
 	populateCountryList();
 
 	connect(ui->citySearchLineEdit, SIGNAL(textChanged(const QString&)), proxyModel, SLOT(setFilterWildcard(const QString&)));
-	connect(ui->citiesListView, SIGNAL(clicked(const QModelIndex&)), this, SLOT(listItemActivated(const QModelIndex&)));
+	connect(ui->citiesListView, SIGNAL(clicked(const QModelIndex&)),
+	        this, SLOT(setPositionFromList(const QModelIndex&)));
 
 	// Connect all the QT signals
 	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
@@ -100,71 +102,76 @@ void LocationDialog::createDialogContent()
 	connect(ui->addLocationToListPushButton, SIGNAL(clicked()), this, SLOT(addCurrentLocationToList()));
 	connect(ui->deleteLocationFromListPushButton, SIGNAL(clicked()), this, SLOT(deleteCurrentLocationFromList()));
 
-	setFieldsFromLocation(StelApp::getInstance().getCore()->getCurrentLocation());
+	StelCore* core = StelApp::getInstance().getCore();
+	const StelLocation& currentLocation = core->getCurrentLocation();
+	setFieldsFromLocation(currentLocation);
 
-	const bool b = StelApp::getInstance().getCore()->getCurrentLocation().getID()
-			==StelApp::getInstance().getCore()->getDefaultLocationID();
-	ui->useAsDefaultLocationCheckBox->setChecked(b);
-	ui->useAsDefaultLocationCheckBox->setEnabled(!b);
-	connect(ui->useAsDefaultLocationCheckBox, SIGNAL(clicked()), this, SLOT(useAsDefaultClicked()));
+	const bool b = (currentLocation.getID() == core->getDefaultLocationID());
+	updateDefaultLocationControls(b);
+	connect(ui->useAsDefaultLocationCheckBox, SIGNAL(clicked()), this, SLOT(setDefaultLocation()));
+	connect(ui->pushButtonReturnToDefault, SIGNAL(clicked()),
+	        core, SLOT(returnToDefaultLocation()));
 
 	connectEditSignals();
-
-	QTimer* refreshTimer = new QTimer(this);
-	connect(refreshTimer, SIGNAL(timeout()), this, SLOT(updateFromProgram()));
-	refreshTimer->start(200);
+	
+	connect(core, SIGNAL(locationChanged(StelLocation)),
+	        this, SLOT(updateFromProgram(StelLocation)));
 
 	ui->citySearchLineEdit->setFocus();
 }
 
 // Update the widget to make sure it is synchrone if the location is changed programmatically
-void LocationDialog::updateFromProgram()
+void LocationDialog::updateFromProgram(const StelLocation& currentLocation)
 {
 	if (!dialog->isVisible())
 		return;
+	
+	StelCore* stelCore = StelApp::getInstance().getCore();
+	//const StelLocation& currentLocation = stelCore->getCurrentLocation();
 
+	// Hack to avoid the coord spinbox receiving the focus and triggering
+	// "new location" editing mode.
+	ui->citySearchLineEdit->setFocus();
+
+	isEditingNew = false;
+	
 	// Check that the use as default check box needs to be updated
-	const bool b = StelApp::getInstance().getCore()->getCurrentLocation().getID() == StelApp::getInstance().getCore()->getDefaultLocationID();
-	if (b!=ui->useAsDefaultLocationCheckBox->isChecked())
-	{
-		ui->useAsDefaultLocationCheckBox->setChecked(b);
-		ui->useAsDefaultLocationCheckBox->setEnabled(!b);
-	}
+	// Move to setFieldsFromLocation()? --BM?
+	const bool b = currentLocation.getID() == stelCore->getDefaultLocationID();
+	updateDefaultLocationControls(b);
 
-	// removing this check and return... we might have the location changed
-	// by a script or plugin, and as such we should update the map whenever the
-	// location window is visible.
-	if (isEditingNew==true)
-		return;
-
-	const QString& key1 = StelApp::getInstance().getCore()->getCurrentLocation().getID();
+	const QString& key1 = currentLocation.getID();
 	const QString& key2 = locationFromFields().getID();
 	if (key1!=key2)
 	{
-		setFieldsFromLocation(StelApp::getInstance().getCore()->getCurrentLocation());
+		setFieldsFromLocation(currentLocation);
 	}
 }
 
 void LocationDialog::disconnectEditSignals()
 {
-	disconnect(ui->longitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(spinBoxChanged()));
-	disconnect(ui->latitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(spinBoxChanged()));
-	disconnect(ui->altitudeSpinBox, SIGNAL(valueChanged(int)), this, SLOT(spinBoxChanged(int)));
-	disconnect(ui->planetNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(comboBoxChanged(const QString&)));
-	disconnect(ui->countryNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(comboBoxChanged(const QString&)));
-	disconnect(ui->countryNameComboBox, SIGNAL(activated(const QString&)), this, SLOT(comboBoxChanged(const QString&)));
-	disconnect(ui->cityNameLineEdit, SIGNAL(textEdited(const QString&)), this, SLOT(locationNameChanged(const QString&)));
+	disconnect(ui->longitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(setPositionFromCoords()));
+	disconnect(ui->latitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(setPositionFromCoords()));
+	disconnect(ui->altitudeSpinBox, SIGNAL(valueChanged(int)), this, SLOT(setPositionFromCoords(int)));
+	disconnect(ui->planetNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(moveToAnotherPlanet(const QString&)));
+	disconnect(ui->countryNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(reportEdit()));
+	// Why an edit should be reported even if the country is not changed? --BM
+	//disconnect(ui->countryNameComboBox, SIGNAL(activated(const QString&)), this, SLOT(comboBoxChanged(const QString&)));
+	disconnect(ui->cityNameLineEdit, SIGNAL(textEdited(const QString&)),
+	           this, SLOT(reportEdit()));
 }
 
 void LocationDialog::connectEditSignals()
 {
-	connect(ui->longitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(spinBoxChanged()));
-	connect(ui->latitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(spinBoxChanged()));
-	connect(ui->altitudeSpinBox, SIGNAL(valueChanged(int)), this, SLOT(spinBoxChanged(int)));
-	connect(ui->planetNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(comboBoxChanged(const QString&)));
-	connect(ui->countryNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(comboBoxChanged(const QString&)));
-	connect(ui->countryNameComboBox, SIGNAL(activated(const QString&)), this, SLOT(comboBoxChanged(const QString&)));
-	connect(ui->cityNameLineEdit, SIGNAL(textEdited(const QString&)), this, SLOT(locationNameChanged(const QString&)));
+	connect(ui->longitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(setPositionFromCoords()));
+	connect(ui->latitudeSpinBox, SIGNAL(valueChanged()), this, SLOT(setPositionFromCoords()));
+	connect(ui->altitudeSpinBox, SIGNAL(valueChanged(int)), this, SLOT(setPositionFromCoords(int)));
+	connect(ui->planetNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(moveToAnotherPlanet(const QString&)));
+	connect(ui->countryNameComboBox, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(reportEdit()));
+	// Why an edit should be reported even if the country is not changed? --BM
+	//connect(ui->countryNameComboBox, SIGNAL(activated(const QString&)), this, SLOT(comboBoxChanged(const QString&)));
+	connect(ui->cityNameLineEdit, SIGNAL(textEdited(const QString&)),
+	        this, SLOT(reportEdit()));
 }
 
 void LocationDialog::setFieldsFromLocation(const StelLocation& loc)
@@ -199,6 +206,12 @@ void LocationDialog::setFieldsFromLocation(const StelLocation& loc)
 
 	ui->deleteLocationFromListPushButton->setEnabled(StelApp::getInstance().getLocationMgr().canDeleteUserLocation(loc.getID()));
 
+	SolarSystem* ssm = GETSTELMODULE(SolarSystem);
+	PlanetP p = ssm->searchByEnglishName(loc.planetName);
+	LandscapeMgr* ls = GETSTELMODULE(LandscapeMgr);
+	ls->setFlagAtmosphere(p->hasAtmosphere());
+	ls->setFlagFog(p->hasAtmosphere());
+
 	// Reactivate edit signals
 	connectEditSignals();
 }
@@ -327,7 +340,7 @@ StelLocation LocationDialog::locationFromFields() const
 	return loc;
 }
 
-void LocationDialog::listItemActivated(const QModelIndex& index)
+void LocationDialog::setPositionFromList(const QModelIndex& index)
 {
 	isEditingNew=false;
 	ui->addLocationToListPushButton->setEnabled(false);
@@ -336,10 +349,7 @@ void LocationDialog::listItemActivated(const QModelIndex& index)
 
 	setFieldsFromLocation(loc);
 	StelApp::getInstance().getCore()->moveObserverTo(loc, 0.);
-
-	const bool b = loc.getID()==StelApp::getInstance().getCore()->getDefaultLocationID();
-	ui->useAsDefaultLocationCheckBox->setChecked(b);
-	ui->useAsDefaultLocationCheckBox->setEnabled(!b);
+	// This calls indirectly updateFromProgram()
 }
 
 void LocationDialog::setPositionFromMap(double longitude, double latitude)
@@ -353,16 +363,17 @@ void LocationDialog::setPositionFromMap(double longitude, double latitude)
 }
 
 // Called when the planet name is changed by hand
-void LocationDialog::comboBoxChanged(const QString&)
+void LocationDialog::moveToAnotherPlanet(const QString&)
 {
 	reportEdit();
 	StelLocation loc = locationFromFields();
-	if (loc.planetName!=StelApp::getInstance().getCore()->getCurrentLocation().planetName)
+	StelCore* stelCore = StelApp::getInstance().getCore();
+	if (loc.planetName != stelCore->getCurrentLocation().planetName)
 		setFieldsFromLocation(loc);
-	StelApp::getInstance().getCore()->moveObserverTo(loc, 0.);
+	stelCore->moveObserverTo(loc, 0.);
 }
 
-void LocationDialog::spinBoxChanged(int )
+void LocationDialog::setPositionFromCoords(int )
 {
 	reportEdit();
 	StelLocation loc = locationFromFields();
@@ -371,12 +382,6 @@ void LocationDialog::spinBoxChanged(int )
 	ui->mapLabel->setCursorPos(loc.longitude, loc.latitude);
 }
 
-// Called when the location name is manually changed
-void LocationDialog::locationNameChanged(const QString&)
-{
-	reportEdit();
-}
-
 void LocationDialog::reportEdit()
 {
 	if (isEditingNew==false)
@@ -387,7 +392,9 @@ void LocationDialog::reportEdit()
 	}
 
 	StelLocation loc = locationFromFields();
-	if (!StelApp::getInstance().getLocationMgr().canSaveUserLocation(loc))
+	StelLocationMgr& locationMgr = StelApp::getInstance().getLocationMgr();
+	bool canSave = locationMgr.canSaveUserLocation(loc);
+	if (!canSave)
 	{
 		if (ui->cityNameLineEdit->hasFocus())
 		{
@@ -403,8 +410,8 @@ void LocationDialog::reportEdit()
 			loc = locationFromFields();
 		}
 	}
-	ui->addLocationToListPushButton->setEnabled(isEditingNew && StelApp::getInstance().getLocationMgr().canSaveUserLocation(loc));
-	ui->deleteLocationFromListPushButton->setEnabled(StelApp::getInstance().getLocationMgr().canDeleteUserLocation(loc.getID()));
+	ui->addLocationToListPushButton->setEnabled(isEditingNew && canSave);
+	ui->deleteLocationFromListPushButton->setEnabled(locationMgr.canDeleteUserLocation(loc.getID()));
 }
 
 // Called when the user clic on the save button
@@ -424,7 +431,7 @@ void LocationDialog::addCurrentLocationToList()
 		{
 			ui->citiesListView->scrollTo(model->index(i,0));
 			ui->citiesListView->selectionModel()->select(model->index(i,0), QItemSelectionModel::ClearAndSelect|QItemSelectionModel::Rows);
-			listItemActivated(model->index(i,0));
+			setPositionFromList(model->index(i,0));
 			disconnectEditSignals();
 			ui->citySearchLineEdit->setFocus();
 			connectEditSignals();
@@ -434,17 +441,17 @@ void LocationDialog::addCurrentLocationToList()
 }
 
 // Called when the user wants to use the current location as default
-void LocationDialog::useAsDefaultClicked()
+void LocationDialog::setDefaultLocation()
 {
 	StelCore* core = StelApp::getInstance().getCore();
-	QString newDefaultLocationId = core->getCurrentLocation().getID();
-	core->setDefaultLocationID(newDefaultLocationId);
-
 	QString currentLocationId = core->getCurrentLocation().getID();
-	const bool show = (currentLocationId == core->getDefaultLocationID());
+	core->setDefaultLocationID(currentLocationId);
+
+	// Why this code even exists? After the previous code, this should always
+	// be true, except if setting the default location somehow fails. --BM
+	bool isDefault = (currentLocationId == core->getDefaultLocationID());
 	disconnectEditSignals();
-	ui->useAsDefaultLocationCheckBox->setChecked(show);
-	ui->useAsDefaultLocationCheckBox->setEnabled(!show);
+	updateDefaultLocationControls(isDefault);
 	//The focus need to be switched to another control, otherwise
 	//ui->latitudeSpinBox receives it and emits a valueChanged() signal when
 	//the window is closed.
@@ -452,9 +459,16 @@ void LocationDialog::useAsDefaultClicked()
 	connectEditSignals();
 }
 
-// Called when the user clic on the delete button
+// Called when the user clicks on the delete button
 void LocationDialog::deleteCurrentLocationFromList()
 {
 	const StelLocation& loc = locationFromFields();
 	StelApp::getInstance().getLocationMgr().deleteUserLocation(loc.getID());
 }
+
+void LocationDialog::updateDefaultLocationControls(bool currentIsDefault)
+{
+	ui->useAsDefaultLocationCheckBox->setChecked(currentIsDefault);
+	ui->useAsDefaultLocationCheckBox->setEnabled(!currentIsDefault);
+	ui->pushButtonReturnToDefault->setEnabled(!currentIsDefault);
+}
