@@ -53,6 +53,13 @@
 #endif
 #include "StelAppGraphicsWidget.hpp"
 
+#include "ConfigurationDialog.hpp"
+#include "DateTimeDialog.hpp"
+#include "HelpDialog.hpp"
+#include "LocationDialog.hpp"
+#include "SearchDialog.hpp"
+#include "ViewDialog.hpp"
+
 #include <QDebug>
 #include <QTimeLine>
 #include <QFontDatabase>
@@ -64,6 +71,8 @@
 #include <QGraphicsWidget>
 #include <QGraphicsGridLayout>
 #include <QClipboard>
+#include <QPalette>
+#include <QColor>
 
 StelGuiBase* StelStandardGuiPluginInterface::getStelGuiBase() const
 {
@@ -74,7 +83,18 @@ StelGuiBase* StelStandardGuiPluginInterface::getStelGuiBase() const
 }
 Q_EXPORT_PLUGIN2(StelGui, StelStandardGuiPluginInterface)
 
-StelGui::StelGui() : topLevelGraphicsWidget(NULL), configurationDialog(NULL), initDone(false)
+StelGui::StelGui() :
+    topLevelGraphicsWidget(NULL),
+    locationDialog(0),
+    helpDialog(0),
+    dateTimeDialog(0),
+    searchDialog(0),
+    viewDialog(0),
+    configurationDialog(0),
+#ifdef ENABLE_SCRIPT_CONSOLE
+    scriptConsole(0),
+#endif
+    initDone(false)
 {
 	// QPixmapCache::setCacheLimit(30000); ?
 	flipHoriz = NULL;
@@ -86,6 +106,40 @@ StelGui::~StelGui()
 {
 	delete skyGui;
 	skyGui = NULL;
+	
+	if (locationDialog)
+	{
+		delete locationDialog;
+		locationDialog = 0;
+	}
+	if (helpDialog)
+	{
+		delete helpDialog;
+		helpDialog = 0;
+	}
+	if (dateTimeDialog)
+	{
+		delete dateTimeDialog;
+		dateTimeDialog = 0;
+	}
+	if (searchDialog)
+	{
+		delete searchDialog;
+		searchDialog = 0;
+	}
+	if (viewDialog)
+	{
+		delete viewDialog;
+		viewDialog = 0;
+	}
+	// configurationDialog is automatically deleted with its parent widget.
+#ifdef ENABLE_SCRIPT_CONSOLE
+	if (scriptConsole)
+	{
+		delete scriptConsole;
+		scriptConsole = 0;
+	}
+#endif
 }
 
 void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidget* astelAppGraphicsWidget)
@@ -95,7 +149,15 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	StelGuiBase::init(atopLevelGraphicsWidget, astelAppGraphicsWidget);
 
 	skyGui = new SkyGui(atopLevelGraphicsWidget);
+	locationDialog = new LocationDialog();
+	helpDialog = new HelpDialog();
+	dateTimeDialog = new DateTimeDialog();
+	searchDialog = new SearchDialog();
+	viewDialog = new ViewDialog();
 	configurationDialog = new ConfigurationDialog(this);
+#ifdef ENABLE_SCRIPT_CONSOLE
+	scriptConsole = new ScriptConsole();
+#endif
 
 	///////////////////////////////////////////////////////////////////////
 	// Create all the main actions of the program, associated with shortcuts
@@ -124,11 +186,12 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	addGuiActions("actionShow_Nebulas", N_("Nebulas"), "N", group, true, false);
 	addGuiActions("actionShow_DSS", N_("Nebulas background images"), "", group, true, false);
 	addGuiActions("actionShow_Stars", N_("Stars"), "S", group, true, false);
+	addGuiActions("actionShow_Stars_Labels", N_("Stars labels"), "Alt+S", group, true, false);
 	addGuiActions("actionShow_Planets_Labels", N_("Planet labels"), "P", group, true, false);
 	addGuiActions("actionShow_Planets_Orbits", N_("Planet orbits"), "O", group, true, false);
 	addGuiActions("actionShow_Planets_Trails", N_("Planet trails"), "Shift+T", group, true, false);
 
-	addGuiActions("actionShow_Night_Mode", N_("Night mode"), "", group, true, false);
+	addGuiActions("actionShow_Night_Mode", N_("Night vision mode"), "Ctrl+N", group, true, false);
 	addGuiActions("actionSet_Full_Screen_Global", N_("Full-screen mode"), "F11", group, true, false, true);
 	addGuiActions("actionHorizontal_Flip", N_("Flip scene horizontally"), "Ctrl+Shift+H", group, true, false);
 	addGuiActions("actionVertical_Flip", N_("Flip scene vertically"), "Ctrl+Shift+V", group, true, false);
@@ -148,6 +211,9 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	addGuiActions("actionDecrease_Script_Speed", N_("Slow down the script execution rate"), "", group, false, false);
 	addGuiActions("actionIncrease_Script_Speed", N_("Speed up the script execution rate"), "", group, false, false);
 	addGuiActions("actionSet_Real_Script_Speed", N_("Set the normal script execution rate"), "", group, false, false);
+	addGuiActions("actionStop_Script", N_("Stop script execution"), "", group, false, false);
+	addGuiActions("actionPause_Script", N_("Pause script execution"), "", group, false, false);
+	addGuiActions("actionResume_Script", N_("Resume script execution"), "", group, false, false);
 	addGuiActions("actionDecrease_Time_Speed", N_("Decrease time speed"), "J", group, false, false);
 	addGuiActions("actionIncrease_Time_Speed", N_("Increase time speed"), "L", group, false, false);
 	addGuiActions("actionSet_Real_Time_Speed", N_("Set normal time rate"), "K", group, false, false);
@@ -182,6 +248,7 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	addGuiActions("actionQuit_Global", N_("Quit"), "Ctrl+Q", group, false, false, true);
 	addGuiActions("actionSave_Screenshot_Global", N_("Save screenshot"), "Ctrl+S", group, false, false, true);
 	addGuiActions("actionSave_Copy_Object_Information_Global", N_("Copy selected object information to clipboard"), "Ctrl+C", group, false, false, true);
+	addGuiActions("actionGo_Home_Global", N_("Go to home"), "Ctrl+H", group, false, false, true);
 	
 	addGuiActions("actionAutoHideHorizontalButtonBar", N_("Auto hide horizontal button bar"), "", group, true, false);
 	addGuiActions("actionAutoHideVerticalButtonBar", N_("Auto hide vertical button bar"), "", group, true, false);
@@ -190,7 +257,7 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 
 	///////////////////////////////////////////////////////////////////////
 	// Connect all the GUI actions signals with the Core of Stellarium
-	connect(getGuiActions("actionQuit_Global"), SIGNAL(triggered()), this, SLOT(quit()));
+	connect(getGuiActions("actionQuit_Global"), SIGNAL(triggered()), this, SLOT(quit()));	
 
 	initConstellationMgr();
 	initGrindLineMgr();
@@ -210,6 +277,9 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	connect(getGuiActions("actionIncrease_Script_Speed"), SIGNAL(triggered()), this, SLOT(increaseScriptSpeed()));
 	connect(getGuiActions("actionDecrease_Script_Speed"), SIGNAL(triggered()), this, SLOT(decreaseScriptSpeed()));
 	connect(getGuiActions("actionSet_Real_Script_Speed"), SIGNAL(triggered()), this, SLOT(setRealScriptSpeed()));
+	connect(getGuiActions("actionStop_Script"), SIGNAL(triggered()), this, SLOT(stopScript()));
+	connect(getGuiActions("actionPause_Script"), SIGNAL(triggered()), this, SLOT(pauseScript()));
+	connect(getGuiActions("actionResume_Script"), SIGNAL(triggered()), this, SLOT(resumeScript()));
 	connect(getGuiActions("actionIncrease_Time_Speed"), SIGNAL(triggered()), core, SLOT(increaseTimeSpeed()));
 	connect(getGuiActions("actionDecrease_Time_Speed"), SIGNAL(triggered()), core, SLOT(decreaseTimeSpeed()));
 	connect(getGuiActions("actionIncrease_Time_Speed_Less"), SIGNAL(triggered()), core, SLOT(increaseTimeSpeedLess()));
@@ -234,6 +304,7 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	connect(getGuiActions("actionSubtract_Sidereal_Month"), SIGNAL(triggered()), core, SLOT(subtractSiderealMonth()));
 	connect(getGuiActions("actionSubtract_Sidereal_Year"), SIGNAL(triggered()), core, SLOT(subtractSiderealYear()));
 	connect(getGuiActions("actionSet_Home_Planet_To_Selected"), SIGNAL(triggered()), core, SLOT(moveObserverToSelected()));
+	connect(getGuiActions("actionGo_Home_Global"), SIGNAL(triggered()), core, SLOT(returnToHome()));
 
 	// connect the actor after setting the nightmode.
 	// StelApp::init() already set flagNightMode for us, don't do it twice!
@@ -249,28 +320,49 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	connect(getGuiActions("actionSet_Full_Screen_Global"), SIGNAL(toggled(bool)), &StelMainWindow::getInstance(), SLOT(setFullScreen(bool)));
 	getGuiActions("actionSet_Full_Screen_Global")->setChecked(StelMainWindow::getInstance().isFullScreen());
 
-	connect(getGuiActions("actionShow_Location_Window_Global"), SIGNAL(toggled(bool)), &locationDialog, SLOT(setVisible(bool)));
-	connect(&locationDialog, SIGNAL(visibleChanged(bool)), getGuiActions("actionShow_Location_Window_Global"), SLOT(setChecked(bool)));
+	QAction* tempAction = getGuiActions("actionShow_Location_Window_Global");
+	connect(tempAction, SIGNAL(toggled(bool)),
+	        locationDialog, SLOT(setVisible(bool)));
+	connect(locationDialog, SIGNAL(visibleChanged(bool)),
+	        tempAction, SLOT(setChecked(bool)));
 
 #ifdef ENABLE_SCRIPT_CONSOLE
-	connect(getGuiActions("actionShow_ScriptConsole_Window_Global"), SIGNAL(toggled(bool)), &scriptConsole, SLOT(setVisible(bool)));
-	connect(&scriptConsole, SIGNAL(visibleChanged(bool)), getGuiActions("actionShow_ScriptConsole_Window_Global"), SLOT(setChecked(bool)));
+	tempAction = getGuiActions("actionShow_ScriptConsole_Window_Global");
+	connect(tempAction, SIGNAL(toggled(bool)),
+	        scriptConsole, SLOT(setVisible(bool)));
+	connect(scriptConsole, SIGNAL(visibleChanged(bool)),
+	        tempAction, SLOT(setChecked(bool)));
 #endif
 
-	connect(getGuiActions("actionShow_Configuration_Window_Global"), SIGNAL(toggled(bool)), configurationDialog, SLOT(setVisible(bool)));
-	connect(configurationDialog, SIGNAL(visibleChanged(bool)), getGuiActions("actionShow_Configuration_Window_Global"), SLOT(setChecked(bool)));
+	tempAction = getGuiActions("actionShow_Configuration_Window_Global");
+	connect(tempAction, SIGNAL(toggled(bool)),
+	        configurationDialog, SLOT(setVisible(bool)));
+	connect(configurationDialog, SIGNAL(visibleChanged(bool)),
+	        tempAction, SLOT(setChecked(bool)));
 
-	connect(getGuiActions("actionShow_SkyView_Window_Global"), SIGNAL(toggled(bool)), &viewDialog, SLOT(setVisible(bool)));
-	connect(&viewDialog, SIGNAL(visibleChanged(bool)), getGuiActions("actionShow_SkyView_Window_Global"), SLOT(setChecked(bool)));
+	tempAction = getGuiActions("actionShow_SkyView_Window_Global");
+	connect(tempAction, SIGNAL(toggled(bool)),
+	        viewDialog, SLOT(setVisible(bool)));
+	connect(viewDialog, SIGNAL(visibleChanged(bool)),
+	        tempAction, SLOT(setChecked(bool)));
 
-	connect(getGuiActions("actionShow_Help_Window_Global"), SIGNAL(toggled(bool)), &helpDialog, SLOT(setVisible(bool)));
-	connect(&helpDialog, SIGNAL(visibleChanged(bool)), getGuiActions("actionShow_Help_Window_Global"), SLOT(setChecked(bool)));
+	tempAction = getGuiActions("actionShow_Help_Window_Global");
+	connect(tempAction, SIGNAL(toggled(bool)),
+	        helpDialog, SLOT(setVisible(bool)));
+	connect(helpDialog, SIGNAL(visibleChanged(bool)),
+	        tempAction, SLOT(setChecked(bool)));
 
-	connect(getGuiActions("actionShow_DateTime_Window_Global"), SIGNAL(toggled(bool)), &dateTimeDialog, SLOT(setVisible(bool)));
-	connect(&dateTimeDialog, SIGNAL(visibleChanged(bool)), getGuiActions("actionShow_DateTime_Window_Global"), SLOT(setChecked(bool)));
+	tempAction = getGuiActions("actionShow_DateTime_Window_Global");
+	connect(tempAction, SIGNAL(toggled(bool)),
+	        dateTimeDialog, SLOT(setVisible(bool)));
+	connect(dateTimeDialog, SIGNAL(visibleChanged(bool)),
+	        tempAction, SLOT(setChecked(bool)));
 
-	connect(getGuiActions("actionShow_Search_Window_Global"), SIGNAL(toggled(bool)), &searchDialog, SLOT(setVisible(bool)));
-	connect(&searchDialog, SIGNAL(visibleChanged(bool)), getGuiActions("actionShow_Search_Window_Global"), SLOT(setChecked(bool)));
+	tempAction = getGuiActions("actionShow_Search_Window_Global");
+	connect(tempAction, SIGNAL(toggled(bool)),
+	        searchDialog, SLOT(setVisible(bool)));
+	connect(searchDialog, SIGNAL(visibleChanged(bool)),
+	        tempAction, SLOT(setChecked(bool)));
 
 	connect(getGuiActions("actionSave_Screenshot_Global"), SIGNAL(triggered()), &StelMainGraphicsView::getInstance(), SLOT(saveScreenShot()));
 	connect(getGuiActions("actionSave_Copy_Object_Information_Global"), SIGNAL(triggered()), this, SLOT(copySelectedObjectInfo()));
@@ -287,6 +379,9 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 	connect(getGuiActions("actionShow_Stars"), SIGNAL(toggled(bool)), smgr, SLOT(setFlagStars(bool)));
 	getGuiActions("actionShow_Stars")->setChecked(smgr->getFlagStars());
 
+	connect(getGuiActions("actionShow_Stars_Labels"), SIGNAL(toggled(bool)), smgr, SLOT(setFlagLabels(bool)));
+	getGuiActions("actionShow_Stars_Labels")->setChecked(smgr->getFlagLabels());
+
 	SolarSystem* ssmgr = GETSTELMODULE(SolarSystem);
 	connect(getGuiActions("actionShow_Planets_Labels"), SIGNAL(toggled(bool)), ssmgr, SLOT(setFlagLabels(bool)));
 	getGuiActions("actionShow_Planets_Labels")->setChecked(ssmgr->getFlagLabels());
@@ -466,6 +561,16 @@ void StelGui::init(QGraphicsWidget* atopLevelGraphicsWidget, StelAppGraphicsWidg
 
 	skyGui->setGeometry(stelAppGraphicsWidget->geometry());
 	skyGui->updateBarsPos();
+
+	// The disabled text for checkboxes is embossed with the QPalette::Light setting for the ColorGroup Disabled.
+	// It doesn't appear to be possible to set this from the stylesheet.  Instead we'll make it 100% transparent
+	// and set the text color for disabled in the stylesheets.
+	QPalette p = QApplication::palette();
+	p.setColor(QPalette::Disabled, QPalette::Light, QColor(0,0,0,0));
+
+	// And this is for the focus...  apparently the focus indicator is the inverted value for Active/Button.
+	p.setColor(QPalette::Active, QPalette::Button, QColor(255,255,255));
+	QApplication::setPalette(p);
 	
 	StelApp *app = &StelApp::getInstance();
 	connect(app, SIGNAL(languageChanged()), this, SLOT(updateI18n()));
@@ -713,13 +818,13 @@ void StelGui::setStelStyle(const QString& section)
 	}
 	qApp->setStyleSheet(currentStelStyle.qtStyleSheet);
 
-	locationDialog.styleChanged();
-	dateTimeDialog.styleChanged();
+	locationDialog->styleChanged();
+	dateTimeDialog->styleChanged();
 	configurationDialog->styleChanged();
-	searchDialog.styleChanged();
-	viewDialog.styleChanged();
+	searchDialog->styleChanged();
+	viewDialog->styleChanged();
 #ifdef ENABLE_SCRIPT_CONSOLE
-	scriptConsole.styleChanged();
+	scriptConsole->styleChanged();
 #endif // ENABLE_SCRIPT_CONSOLE
 }
 
@@ -809,7 +914,7 @@ void StelGui::update()
 		skyGui->updateBarsPos();
 	}
 
-	dateTimeDialog.setDateTime(core->getJDay());
+	dateTimeDialog->setDateTime(core->getJDay());
 }
 
 // Add a new progress bar in the lower right corner of the screen.
@@ -829,6 +934,10 @@ void StelGui::setScriptKeys(bool b)
 		getGuiActions("actionDecrease_Script_Speed")->setShortcut(QKeySequence("J"));
 		getGuiActions("actionIncrease_Script_Speed")->setShortcut(QKeySequence("L"));
 		getGuiActions("actionSet_Real_Script_Speed")->setShortcut(QKeySequence("K"));
+
+		getGuiActions("actionStop_Script")->setShortcut(QKeySequence("4"));
+		getGuiActions("actionPause_Script")->setShortcut(QKeySequence("5"));
+		getGuiActions("actionResume_Script")->setShortcut(QKeySequence("6"));
 	}
 	else
 	{
@@ -855,6 +964,21 @@ void StelGui::setRealScriptSpeed()
 {	
 	StelMainGraphicsView::getInstance().getScriptMgr().setScriptRate(1);	
 }
+
+void StelGui::stopScript()
+{	
+	StelMainGraphicsView::getInstance().getScriptMgr().stopScript();	
+}
+
+void StelGui::pauseScript()
+{	
+	StelMainGraphicsView::getInstance().getScriptMgr().pauseScript();	
+}
+
+void StelGui::resumeScript()
+{	
+	StelMainGraphicsView::getInstance().getScriptMgr().resumeScript();	
+}
 #endif
 
 void StelGui::setFlagShowFlipButtons(bool b)
@@ -1014,7 +1138,7 @@ void StelGui::setGuiVisible(bool b)
 QAction* StelGui::addGuiActions(const QString& actionName, const QString& text, const QString& shortCut, const QString& helpGroup, bool checkable, bool autoRepeat, bool global)
 {
 	if (!shortCut.isEmpty())
-		helpDialog.setKey(helpGroup, "", shortCut, text);
+		helpDialog->setKey(helpGroup, "", shortCut, text);
 	return StelGuiBase::addGuiActions(actionName, text, shortCut, helpGroup, checkable, autoRepeat, global);
 }
 
