@@ -106,8 +106,10 @@ public slots:
 	//! @param name is the English name of the object for which data will be
 	//! returned.
 	//! @return a map of object data.  Keys:
-	//! - altitude : altitude angle in decimal degrees
-	//! - azimuth : azimuth angle in decimal degrees
+	//! - altitude : apparent altitude angle in decimal degrees
+	//! - azimuth : apparent azimuth angle in decimal degrees
+	//! - altitude-geometric : geometric altitude angle in decimal degrees
+	//! - azimuth-geometric : geometric azimuth angle in decimal degrees
 	//! - ra : right ascension angle (current date frame) in decimal degrees
 	//! - dec : declenation angle in (current date frame) decimal degrees
 	//! - raJ2000 : right ascension angle (J2000 frame) in decimal degrees
@@ -201,6 +203,15 @@ public slots:
 	//! Get the ID of the current observer location.
 	QString getObserverLocation();
 
+	//! Get the info of the current observer location.
+	//! @return a map of object data.  Keys:
+	//! - altitude : altitude in meters
+	//! - longitude : longitude in decimal degrees
+	//! - latitude : latitude in decimal degrees
+	//! - planet : name of planet
+	//! - location : city and country
+	QVariantMap getObserverLocationInfo();
+
 	//! Save a screenshot.
 	//! @param prefix the prefix for the file name to use
 	//! @param dir the path of the directory to save the screenshot in.  If
@@ -320,6 +331,7 @@ public slots:
 					  double ra3, double dec3,
 					  double minRes=2.5, double maxBright=14, bool visible=true);
 
+
 	//! Convenience function which allows the user to provide RA and DEC angles
 	//! as strings (e.g. "12d 14m 8s" or "5h 26m 8s" - formats accepted by
 	//! StelUtils::getDecAngle()).
@@ -356,6 +368,49 @@ public slots:
 					  const QString& ra, const QString& dec, double angSize, double rotation,
 					  double minRes=2.5, double maxBright=14, bool visible=true);
 
+	//! Load an image which will have sky coordinates.
+	//! @param id a string ID to be used when referring to this
+	//! image (e.g. when changing the displayed status or deleting
+	//! it.
+	//! @param filename the file name of the image.  If a relative
+	//! path is specified, "scripts/" will be prefixed before the
+	//! image is searched for using StelFileMgr.
+	//! @param alt0 The altitude angle of the first corner of the image in degrees
+	//! @param azi0 The azimuth angle of the first corner of the image in degrees
+	//! @param alt1 The altitude angle of the second corner of the image in degrees
+	//! @param azi1 The azimuth angle of the second corner of the image in degrees
+	//! @param alt2 The altitude angle of the third corner of the image in degrees
+	//! @param azi2 The azimuth angle of the third corner of the image in degrees
+	//! @param alt3 The altitude angle of the fourth corner of the image in degrees
+	//! @param azi3 The azimuth angle of the fourth corner of the image in degrees
+	//! @param minRes The minimum resolution setting for the image
+	//! @param maxBright The maximum brightness setting for the image
+	//! @param visible The initial visibility of the image
+	void loadSkyImageAltAz(const QString& id, const QString& filename,
+					  double alt0, double azi0,
+					  double alt1, double azi1,
+					  double alt2, double azi2,
+					  double alt3, double azi3,
+					  double minRes=2.5, double maxBright=14, bool visible=true);
+
+	//! Convenience function which allows loading of a sky image based on a
+	//! central coordinate, angular size and rotation.
+	//! @param id a string ID to be used when referring to this
+	//! image (e.g. when changing the displayed status or deleting it.
+	//! @param filename the file name of the image.  If a relative
+	//! path is specified, "scripts/" will be prefixed before the
+	//! image is searched for using StelFileMgr.
+	//! @param alt The altitude angle of the center of the image in degrees
+	//! @param azi The azimuth angle of the center of the image in degrees
+	//! @param angSize The angular size of the image in arc minutes
+	//! @param rotation The clockwise rotation angle of the image in degrees
+	//! @param minRes The minimum resolution setting for the image
+	//! @param maxBright The maximum brightness setting for the image
+	//! @param visible The initial visibility of the image
+	void loadSkyImageAltAz(const QString& id, const QString& filename,
+					  double alt, double azi, double angSize, double rotation,
+					  double minRes=2.5, double maxBright=14, bool visible=true);
+
 	//! Remove a SkyImage.
 	//! @param id the ID of the image to remove.
 	void removeSkyImage(const QString& id);
@@ -386,6 +441,63 @@ public slots:
 	//! @param id the identifier used when loadSound was called
 	void dropSound(const QString& id);
 
+	//! Load a video from a file.
+	//! @param filename the name of the file to load.
+	//! @param id the identifier which will be used to refer to the video
+	//! when calling playVideo, pauseVideo, stopVideo and dropVideo.
+	//! @param x  the x-coordinate for the video widget.
+	//! @param y  the y-coordinate for the video widget.
+	//! @param show  the visibility state for the video.
+	//! @param alpha the initial alpha value of the video.
+	void loadVideo(const QString& filename, const QString& id, float x, float y, bool show, float alpha);
+
+	//! Play a video which has previously been loaded with loadVideo
+	//! @param id the identifier used when loadVideo was called
+	void playVideo(const QString& id);
+
+	//! Pause a video which is playing.  Subsequent playVideo calls will
+	//! resume playing from the position in the file when it was paused.
+	//! @param id the identifier used when loadVideo was called
+	void pauseVideo(const QString& id);
+
+	//! Stop a video from playing.  This resets the position in the
+	//! video to the start so that subsequent playVideo calls will
+	//! start from the beginning.
+	//! @param id the identifier used when loadVideo was called
+	void stopVideo(const QString& id);
+
+	//! Drop a video from memory.  You should do this before the end
+	//! of your script.
+	//! @param id the identifier used when loadVideo was called
+	void dropVideo(const QString& id);
+
+	//! Seeks a video to the requested time.
+	//! @param id the identifier used when loadVideo was called
+	//! @param ms the time in milliseconds from the start of the media.
+        void seekVideo(const QString& id, qint64 ms);                                   
+
+	//! Sets the position of the video widget.
+	//! @param id the identifier used when loadVideo was called
+	//! @param x the new x-coordinate for the video. 
+	//! @param y the new y-coordinate for the video. 
+        void setVideoXY(const QString& id, float x, float y);                           
+
+	//! Set the alpha value of a video when visible.
+	//! @param id the identifier used when loadVideo was called
+	//! @param alpha the new alpha value to set.
+        void setVideoAlpha(const QString& id, float alpha);                             
+
+	//! Resize the video widget to the specified width, height. 
+	//! @param id the identifier used when loadVideo was called
+	//! @param w the new width for the widget.
+	//! @param h the new height for the widget.
+        void resizeVideo(const QString& id, float w, float h);
+
+	//! Set the visibility state of a video.
+	//! @param id the identifier used when loadVideo was called
+	//! @param show the new visible state of the video.
+        void showVideo(const QString& id, bool show);
+
 	//! Get the screen width in pixels.
 	//! @return The screen width in pixels
 	int getScreenWidth();
@@ -402,6 +514,10 @@ public slots:
 	//! if the script rate was 1.
 	void setScriptRate(double r);
 
+	//! Pause the currently running script. Note that you may need to use 
+	//! the key '6' or the GUI to resume script execution.
+	void pauseScript();
+
 	//! Set the amount of selected object information to display
 	//! @param level can be "AllInfo", "ShortInfo", "None"
 	void setSelectedObjectInfo(const QString& level);
@@ -432,6 +548,9 @@ public slots:
 	//! @param langCode two letter language code, e.g. "en", or "de".
 	void setSkyLanguage(QString langCode);
 
+	//! Go to defaults position and direction of view
+	void goHome();
+
 	//! For use in setDate and waitFor
 	//! For parameter descriptions see setDate().
 	//! @returns Julian day.
@@ -444,6 +563,13 @@ signals:
 							 double c5, double c6,
 							 double c7, double c8,
 							 double minRes, double maxBright, bool visible);
+	void requestLoadSkyImageAltAz(const QString& id, const QString& filename,
+							 double c1, double c2,
+							 double c3, double c4,
+							 double c5, double c6,
+							 double c7, double c8,
+							 double minRes, double maxBright, bool visible);
+
 
 	void requestRemoveSkyImage(const QString& id);
 
@@ -452,11 +578,23 @@ signals:
 	void requestPauseSound(const QString& id);
 	void requestStopSound(const QString& id);
 	void requestDropSound(const QString& id);
+	void requestLoadVideo(const QString& filename, const QString& id, float x, float y, bool show, float alpha);
+	void requestPlayVideo(const QString& id);
+	void requestPauseVideo(const QString& id);
+	void requestStopVideo(const QString& id);
+	void requestDropVideo(const QString& id);
+	void requestSeekVideo(const QString& id, qint64 ms);
+	void requestSetVideoXY(const QString& id, float x, float y);
+	void requestSetVideoAlpha(const QString& id, float alpha);
+	void requestResizeVideo(const QString& id, float w, float h);
+	void requestShowVideo(const QString& id, bool show);
+	
 	void requestSetNightMode(bool b);
 	void requestSetProjectionMode(QString id);
 	void requestSetSkyCulture(QString id);
 	void requestSetDiskViewport(bool b);
 	void requestExit();
+	void requestSetHomePosition();
 };
 
 #endif // _STELMAINSCRIPTAPI_HPP_
